@@ -7,12 +7,12 @@ use Carp;
 #==================================================================
 # Author    : Djibril Ousmanou
 # Copyright : 2009
-# Update    : 13/04/2009 02:06:29
+# Update    : 12/05/2009 15:53:15
 # AIM       : Create bars chart
 #==================================================================
 
 use vars qw($VERSION);
-$VERSION = '1.01';
+$VERSION = '1.03';
 
 use base qw/Tk::Derived Tk::Canvas/;
 use Tk::Balloon;
@@ -66,6 +66,8 @@ sub Populate {
       'PASSIVE', 'Xvaluespace', 'XValueSpace',
       $CompositeWidget->{RefInfoDummies}->{Axis}{Xaxis}{ScaleValuesHeight}
     ],
+    -xvalueview    => [ 'PASSIVE', 'Xvalueview', 'XValueView', 1 ],
+    -yvalueview     => [ 'PASSIVE', 'Yvalueview', 'YValueView', 1 ],    
     -xvaluesregex => [ 'PASSIVE', 'Xvaluesregex', 'XValuesRegex', qr/.+/ ],
 
     -ylabel      => [ 'PASSIVE', 'Ylabel',      'YLabel',      undef ],
@@ -565,6 +567,7 @@ sub _title {
   my $Title      = $CompositeWidget->cget( -title );
   my $TitleColor = $CompositeWidget->cget( -titlecolor );
   my $TitleFont  = $CompositeWidget->cget( -titlefont );
+  my $titleposition = $CompositeWidget->cget( -titleposition );
 
   # Title verification
   unless ($Title) {
@@ -594,13 +597,29 @@ sub _title {
     = $CompositeWidget->{RefInfoDummies}->{Axis}{Xaxis}{Width};
 
   # display title
+  my $anchor;
+  if ( $titleposition eq 'left' ) {
+    $CompositeWidget->{RefInfoDummies}->{Title}{Ctitrex} = $WidthEmptyBeforeTitle;
+    $anchor = 'nw';
+    $CompositeWidget->{RefInfoDummies}->{Title}{'-width'} = 0;
+  }
+  elsif  ( $titleposition eq 'right' ) {
+    $CompositeWidget->{RefInfoDummies}->{Title}{Ctitrex} = $WidthEmptyBeforeTitle + $CompositeWidget->{RefInfoDummies}->{Axis}{Xaxis}{Width};
+    $CompositeWidget->{RefInfoDummies}->{Title}{'-width'} = 0;
+    $anchor = 'ne';
+  }
+  else  {
+    $anchor = 'center';
+  }
   $CompositeWidget->{RefInfoDummies}->{Title}{IdTitre}
     = $CompositeWidget->createText(
     $CompositeWidget->{RefInfoDummies}->{Title}{Ctitrex},
     $CompositeWidget->{RefInfoDummies}->{Title}{Ctitrey},
     -text  => $Title,
     -width => $CompositeWidget->{RefInfoDummies}->{Title}{'-width'},
+    -anchor => $anchor,
     );
+    return if ( $anchor =~ m{^left|right$} );
 
   # get title information
   my ($Height);
@@ -1417,6 +1436,14 @@ sub _GraphForDummiesConstruction {
     $CompositeWidget->delete(
       $CompositeWidget->{RefInfoDummies}->{TAGS}{xValues} );
   }
+  if ( $CompositeWidget->cget( -xvalueview ) == 0 ) {
+    $CompositeWidget->delete(
+      $CompositeWidget->{RefInfoDummies}->{TAGS}{xValues} );
+  }
+  if ( $CompositeWidget->cget( -yvalueview ) == 0 ) {
+    $CompositeWidget->delete(
+      $CompositeWidget->{RefInfoDummies}->{TAGS}{yValues} );
+  }
 
   # ticks
   my $alltickview = $CompositeWidget->cget( -alltickview );
@@ -1751,6 +1778,18 @@ Title of your graph.
 
 Default : B<undef>
 
+=item Name:	B<Titleposition>
+
+=item Class:	B<TitlePosition>
+
+=item Switch:	B<-titleposition>
+
+Position of title : B<center>, B<left> or B<right>
+  
+ -titleposition => 'left',
+
+Default : B<center>
+
 =item Name:	B<Titlecolor>
 
 =item Class: B<TitleColor>
@@ -1878,6 +1917,18 @@ Width for x values space.
 
 Default : B<30>
 
+=item Name:	B<Xvalueview>
+
+=item Class:	B<XvalueView>
+
+=item Switch:	B<-xvalueview>
+
+View values on x axis.
+ 
+ -xvalueview => 0, # 0 or 1
+
+Default : B<1>
+
 =item Name:	B<Xvaluesregex>
 
 =item Class:	B<XValuesRegex>
@@ -1957,6 +2008,18 @@ Set the color of y values. See also valuecolor option.
 
 Default : B<black>
 
+=item Name:	B<Yvalueview>
+
+=item Class:	B<YvalueView>
+
+=item Switch:	B<-yvalueview>
+
+View values on y axis.
+ 
+ -yvalueview => 0, # 0 or 1
+
+Default : B<1>
+
 =item Name:	B<Labelscolor>
 
 =item Class: B<LabelsColor>
@@ -2047,7 +2110,7 @@ Default : B<0>
 
 =item Switch:	B<-zeroaxis>
 
-If set to a true value, the axis for y values of 0 will always be drawn. 
+If set to a true value, the axis for y values will only be drawn. 
 This might be useful in case your graph contains negative values, 
 but you want it to be clear where the zero value is
 (see also zeroaxisonly and boxaxis).
@@ -2178,28 +2241,6 @@ will have the color of the first array case (red).
 
 =back
 
-=head1 WIDGET-SPECIFIC OPTIONS like Tk::ForDummies::Graph::Lines
-
-Many options allow you to configure your chart as you want. 
-The default configuration is already OK, but you can change it.
-these are the same options as L<Tk::ForDummies::Graph::Lines> module
-
-=over 4
-
-=item Name:	B<Title>
-
-=item Class: B<Title>
-
-=item Switch:	B<-title>
-
-Title of your graph.
-
- -title => "My graph title",
-
-Default : B<undef>
-
-=back
-
 =head1 WIDGET METHODS
 
 The Canvas method creates a widget object. This object supports the 
@@ -2225,11 +2266,11 @@ Your chart will be updade.
 I<Data array reference>
 
 Fill an array of arrays with the values of the datasets (I<\@data>). 
-Make sure that every array has the same size, otherwise Tk::ForDummies::Graph::Boxplots 
+Make sure that every array has the same size, otherwise Tk::ForDummies::Graph::Lines 
 will complain and refuse to compile the graph.
 
  my @NewData = (1,10,12,5,4);
- $GraphDummies>->(\@NewData);
+ $GraphDummies->add_data(\@NewData);
 
 If your last chart has a legend, you have to add a legend entry for the new dataset. Otherwise, 
 the legend chart will not be display (see below).
@@ -2240,7 +2281,7 @@ I<$legend>
 
  my @NewData = (1,10,12,5,4);
  my $legend = "New data set";
- $GraphDummies>->(\@NewData, $legend);
+ $GraphDummies->add_data(\@NewData, $legend);
 
 =back
 
