@@ -7,12 +7,12 @@ use Carp;
 #==================================================================
 # Author    : Djibril Ousmanou
 # Copyright : 2009
-# Update    : 13/04/2009 03:21:45
+# Update    : 12/05/2009 15:53:21
 # AIM       : Create line chart
 #==================================================================
 
 use vars qw($VERSION);
-$VERSION = '1.04';
+$VERSION = '1.06';
 
 use base qw/Tk::Derived Tk::Canvas/;
 use Tk::Balloon;
@@ -67,6 +67,8 @@ sub Populate {
       'PASSIVE', 'Xvaluespace', 'XValueSpace',
       $CompositeWidget->{RefInfoDummies}->{Axis}{Xaxis}{ScaleValuesHeight}
     ],
+    -xvalueview    => [ 'PASSIVE', 'Xvalueview', 'XValueView', 1 ],
+    -yvalueview     => [ 'PASSIVE', 'Yvalueview', 'YValueView', 1 ],    
     -xvaluesregex => [ 'PASSIVE', 'Xvaluesregex', 'XValuesRegex', qr/.+/ ],
 
     -ylabel      => [ 'PASSIVE', 'Ylabel',      'YLabel',      undef ],
@@ -574,6 +576,7 @@ sub _title {
   my $Title      = $CompositeWidget->cget( -title );
   my $TitleColor = $CompositeWidget->cget( -titlecolor );
   my $TitleFont  = $CompositeWidget->cget( -titlefont );
+  my $titleposition = $CompositeWidget->cget( -titleposition );
 
   # Title verification
   unless ($Title) {
@@ -600,13 +603,29 @@ sub _title {
     = $CompositeWidget->{RefInfoDummies}->{Axis}{Xaxis}{Width};
 
   # display title
+  my $anchor;
+  if ( $titleposition eq 'left' ) {
+    $CompositeWidget->{RefInfoDummies}->{Title}{Ctitrex} = $WidthEmptyBeforeTitle;
+    $anchor = 'nw';
+    $CompositeWidget->{RefInfoDummies}->{Title}{'-width'} = 0;
+  }
+  elsif  ( $titleposition eq 'right' ) {
+    $CompositeWidget->{RefInfoDummies}->{Title}{Ctitrex} = $WidthEmptyBeforeTitle + $CompositeWidget->{RefInfoDummies}->{Axis}{Xaxis}{Width};
+    $CompositeWidget->{RefInfoDummies}->{Title}{'-width'} = 0;
+    $anchor = 'ne';
+  }
+  else  {
+    $anchor = 'center';
+  }
   $CompositeWidget->{RefInfoDummies}->{Title}{IdTitre}
     = $CompositeWidget->createText(
     $CompositeWidget->{RefInfoDummies}->{Title}{Ctitrex},
     $CompositeWidget->{RefInfoDummies}->{Title}{Ctitrey},
     -text  => $Title,
     -width => $CompositeWidget->{RefInfoDummies}->{Title}{'-width'},
+    -anchor => $anchor,
     );
+    return if ( $anchor =~ m{^left|right$} );
 
   # get title information
   my ($Height);
@@ -1340,6 +1359,14 @@ sub _GraphForDummiesConstruction {
     $CompositeWidget->delete(
       $CompositeWidget->{RefInfoDummies}->{TAGS}{xValues} );
   }
+  if ( $CompositeWidget->cget( -xvalueview ) == 0 ) {
+    $CompositeWidget->delete(
+      $CompositeWidget->{RefInfoDummies}->{TAGS}{xValues} );
+  }
+  if ( $CompositeWidget->cget( -yvalueview ) == 0 ) {
+    $CompositeWidget->delete(
+      $CompositeWidget->{RefInfoDummies}->{TAGS}{yValues} );
+  }
 
   # ticks
   my $alltickview = $CompositeWidget->cget( -alltickview );
@@ -1651,6 +1678,18 @@ Title of your graph.
 
 Default : B<undef>
 
+=item Name:	B<Titleposition>
+
+=item Class:	B<TitlePosition>
+
+=item Switch:	B<-titleposition>
+
+Position of title : B<center>, B<left> or B<right>
+  
+ -titleposition => 'left',
+
+Default : B<center>
+
 =item Name:	B<Titlecolor>
 
 =item Class:	B<TitleColor>
@@ -1778,6 +1817,18 @@ Width for x values space.
 
 Default : B<30>
 
+=item Name:	B<Xvalueview>
+
+=item Class:	B<XvalueView>
+
+=item Switch:	B<-xvalueview>
+
+View values on x axis.
+ 
+ -xvalueview => 0, # 0 or 1
+
+Default : B<1>
+
 =item Name:	B<Xvaluesregex>
 
 =item Class:	B<XValuesRegex>
@@ -1858,6 +1909,18 @@ Set the color of y values. See also valuecolor option.
 
 Default : B<black>
 
+=item Name:	B<Yvalueview>
+
+=item Class:	B<YvalueView>
+
+=item Switch:	B<-yvalueview>
+
+View values on y axis.
+ 
+ -yvalueview => 0, # 0 or 1
+
+Default : B<1>
+
 =item Name:	B<Labelscolor>
 
 =item Class:	B<LabelsColor>
@@ -1949,7 +2012,7 @@ Default : B<0>
 
 =item Switch:	B<-zeroaxis>
 
-If set to a true value, the axis for y values of 0 will always be drawn. 
+If set to a true value, the axis for y values will only be drawn. 
 This might be useful in case your graph contains negative values, 
 but you want it to be clear where the zero value is. 
 (see also zeroaxisonly and boxaxis).
@@ -2187,7 +2250,7 @@ Make sure that every array has the same size, otherwise Tk::ForDummies::Graph::L
 will complain and refuse to compile the graph.
 
  my @NewData = (1,10,12,5,4);
- $GraphDummies>->(\@NewData);
+ $GraphDummies->add_data(\@NewData);
 
 If your last chart has a legend, you have to add a legend entry for the new dataset. Otherwise, 
 the legend chart will not be display (see below).
@@ -2198,8 +2261,7 @@ I<$legend>
 
  my @NewData = (1,10,12,5,4);
  my $legend = "New data set";
- $GraphDummies>->(\@NewData, $legend);
-  
+ $GraphDummies->add_data(\@NewData, $legend);
 
 =back
 
@@ -2304,10 +2366,12 @@ resolv the bug.
  # xlabel will be changed but not displayed if you not resize the widget.
   
  ...
- $fenetre->Button(-text => "Change xlabel", -command => sub { 
-   $GraphDummies->configure(-xlabel => "red"); 
-   $GraphDummies->redraw; 
-   } 
+ $fenetre->Button(
+   -text    => "Change xlabel", 
+   -command => sub { 
+     $GraphDummies->configure( -xlabel => "red" ); 
+     $GraphDummies->redraw; 
+   }, 
  )->pack;
  ...
  # OK, xlabel will be changed and displayed without resize the widget.
